==> wls-plugin-1.3-sources.jar: com/xebialabs/deployit/plugin/wls/step/StartStopStepFactory.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;
import com.xebialabs.deployit.plugin.wls.ci.WlsServer;

/**
 * provide Start and Stop steps depending of the Domaine Configuration (StartMode)
 */
public class StartStopStepFactory {

	public Step getStartStep(WlsServer server) {
		final WlsDomain domain = server.getDomain();
		switch (domain.getStartMode()) {
			case NodeManager:
				return new StartWlsServerStep(server);
			case Script:
				return new StartWlsServerWithScriptStep(server);
			case WindowsService:
				return new StartWlsServerWithWindowsService(server);

		}
		throw new RuntimeException("StartMode unknown " + domain.getStartMode());
	}

	public Step getStopStep(WlsServer server) {
		final WlsDomain domain = server.getDomain();
		switch (domain.getStartMode()) {
			case NodeManager:
				return new StopWlsServerStep(server);
			case Script:
				return new StopWlsServerWithScriptStep(server);
			case WindowsService:
				return new StopWlsServerWithWindowsService(server);

		}
		throw new RuntimeException("StartMode unknown " + domain.getStartMode());
	}


}

==> wls-plugin-1.4-sources.jar: com/xebialabs/deployit/plugin/wls/step/StartStopStepFactory.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.wls.step;

import com.google.common.collect.Sets;
import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.plugin.wls.ci.WlsCluster;
import com.xebialabs.deployit.plugin.wls.ci.WlsDomain;
import com.xebialabs.deployit.plugin.wls.ci.WlsServer;
import com.xebialabs.deployit.plugin.wls.ci.WlsTarget;

import java.util.Collections;
import java.util.Set;

/**
 * provide Start and Stop steps depending of the Domaine Configuration (StartMode)
 */
public class StartStopStepFactory {

	public Step getStartStep(WlsServer server) {
		final WlsDomain domain = server.getDomain();
		switch (domain.getStartMode()) {
			case NodeManager:
				return new StartWlsServerStep(server);
			case Script:
				return new StartWlsServerWithScriptStep(server);
			case WindowsService:
				return new StartWlsServerWithWindowsService(server);

		}
		throw new RuntimeException("StartMode unknown " + domain.getStartMode());
	}

	public Step getStopStep(WlsServer server) {
		final WlsDomain domain = server.getDomain();
		switch (domain.getStartMode()) {
			case NodeManager:
				return new StopWlsServerStep(server);
			case Script:
				return new StopWlsServerWithScriptStep(server);
			case WindowsService:
				return new StopWlsServerWithWindowsService(server);

		}
		throw new RuntimeException("StartMode unknown " + domain.getStartMode());
	}


	public Set<Step> getStartStep(WlsTarget target) {
		if (target instanceof WlsServer)   {
			return Collections.singleton(getStartStep((WlsServer)target));
		}
		if (target instanceof WlsCluster) {
			WlsCluster cluster= (WlsCluster) target;
			Set<Step> steps = Sets.newHashSet();
			for (WlsServer s: cluster.getServers())
				steps.add(getStartStep(s));
			return steps;
		}

		throw new RuntimeException("WlsTarget unknown " + target);
	}

	public Set<Step> getStopStep(WlsTarget target) {
		if (target instanceof WlsServer)   {
			return Collections.singleton(getStopStep((WlsServer)target));
		}
		if (target instanceof WlsCluster) {
			WlsCluster cluster= (WlsCluster) target;
			Set<Step> steps = Sets.newHashSet();
			for (WlsServer s: cluster.getServers())
				steps.add(getStopStep(s));
			return steps;
		}

		throw new RuntimeException("WlsTarget unknown " + target);
	}


}
